@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -47,6 +47,12 @@ has lowercase => (
 );
 
 
+has digits => (
+    is      => 'ro',
+    default => sub { 0 },
+);
+
+
 has counts => (
     is       => 'ro',
     init_arg => undef,
@@ -92,6 +98,9 @@ sub _process_ngrams {
         my $pat = $self->punctuation;
         $p =~ s/$pat//g if $pat; # Remove unwanted punctuation
 
+        $p =~ s/\d//g if $self->digits; # Remove unwanted digits
+
+        # Skip if we don't have an ngram of the requested size anymore
         my @p = grep { $_ } split /\s/, $p;
         next unless @p == $size;
 
@@ -172,7 +181,7 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0300
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -220,6 +229,10 @@ Default: qr/[-!"#$%&()*+,.\/\\:;<=>?@\[\]^_`{|}~]/
 
 Boolean to render the ngrams in lowercase.  Default is 0.
 
+=head2 digits
+
+Boolean to exclude digits from the ngram results.  Default is 0.
+
 =head2 counts
 
 HashRef of the ngram counts of each processed file.  This is a computed
@@ -239,7 +252,8 @@ attribute - providing it in the constructor will be ignored.
     size        => $size,
     stopwords   => $stopwords,
     punctuation => $punctuation,
-    lowercase   => $boolean,
+    lowercase   => $lowercase,
+    digits      => $digits,
   );
 
 Create a new C<Text::TFIDF::Ngram> object.  If the B<files> argument is passed
